==> ocamlnet_0.97.orig.tar.gz: ocamlnet-0.97/src/cgi/netcgi_fcgi_10.mli <==
(* $Id: netcgi_fcgi_10.mli,v 1.1 2003/10/07 17:39:32 stolpmann Exp $
 * ----------------------------------------------------------------------
 *
 *)

(* This code is copyright 2003 Eric Stokes, and may be used under
either, the GNU GPL, or the same license as ocamlnet *)

(* This module impliments the low level fastcgi wire protocal. It exports
   simple functions to interact with the web server much as a standard cgi 
   script would (eg. fastcgi_write_stdout, fastcgi_write_stderr), this is 
   one of the design goals of the fastcgi protocal. This module is marginally
   usefull for making low level web apps by itself, though you should not 
   mix calls to fcgi_write_* with transactional buffered output, unless 
   you really like your, your helpdesk operators :P 
*)

(* protocal header *)
type fcgiHeader = {version: int; rtype: int; requestid: int; contentlen: int; padlen: int}

(* begin request *)
type fcgiBeginRequestBody = {role: int; flags: int}

(* end request *)
type fcgiEndRequestBody = {astatus: int; pstatus: int}

(* fcgi params will return an asociation list *)
(* fcgi stdin will return a string *)

(* a full request record, what you get when you call fcgi_accept *)
type fcgiRequest = {id: int; 
		    app_type: int;
		    params: (string * string) list;  (* environment variables *)
		    stdin: string; (* used by all *)
		    data: string; (* used only by filter *)
		    con: Unix.file_descr}


(* accept a fastcgi connection *)
val fcgi_accept: unit -> fcgiRequest

(* tear down a connection after finishing with it *)
val fcgi_destroy: fcgiRequest -> unit

(* write to fcgi stdout *)
val fcgi_write_stdout: fcgiRequest -> string -> unit

(* write to fcgi stderr *)
val fcgi_write_stderr: fcgiRequest -> string -> unit

(* write an end request record *)
val fcgi_write_end_request: fcgiRequest -> fcgiEndRequestBody -> unit

(* ======================================================================
 * History:
 * 
 * $Log: netcgi_fcgi_10.mli,v $
 * Revision 1.1  2003/10/07 17:39:32  stolpmann
 * 	Imported Eric's patch for fastcgi
 *
 * 
 *)

==> ocamlnet-0.98.tar.gz: ocamlnet-0.98/src/cgi/netcgi_fcgi_10.mli <==
(* $Id: netcgi_fcgi_10.mli,v 1.2 2004/07/24 18:30:49 stolpmann Exp $
 * ----------------------------------------------------------------------
 *
 *)

(** Low-level FastCGI Wire Protocol *)

(** This code is copyright 2003 Eric Stokes, and may be used under
either, the GNU GPL, or the same license as ocamlnet *)

(** This module impliments the low level fastcgi wire protocal. It exports
   simple functions to interact with the web server much as a standard cgi 
   script would (eg. fastcgi_write_stdout, fastcgi_write_stderr), this is 
   one of the design goals of the fastcgi protocal. This module is marginally
   usefull for making low level web apps by itself, though you should not 
   mix calls to fcgi_write_* with transactional buffered output, unless 
   you really like your, your helpdesk operators :P 
*)

(* protocal header *)
type fcgiHeader = {version: int; rtype: int; requestid: int; contentlen: int; padlen: int}

(* begin request *)
type fcgiBeginRequestBody = {role: int; flags: int}

(* end request *)
type fcgiEndRequestBody = {astatus: int; pstatus: int}

(* fcgi params will return an asociation list *)
(* fcgi stdin will return a string *)

(* a full request record, what you get when you call fcgi_accept *)
type fcgiRequest = {id: int; 
		    app_type: int;
		    params: (string * string) list;  (* environment variables *)
		    stdin: string; (* used by all *)
		    data: string; (* used only by filter *)
		    con: Unix.file_descr}


(* accept a fastcgi connection *)
val fcgi_accept: unit -> fcgiRequest

(* tear down a connection after finishing with it *)
val fcgi_destroy: fcgiRequest -> unit

(* write to fcgi stdout *)
val fcgi_write_stdout: fcgiRequest -> string -> unit

(* write to fcgi stderr *)
val fcgi_write_stderr: fcgiRequest -> string -> unit

(* write an end request record *)
val fcgi_write_end_request: fcgiRequest -> fcgiEndRequestBody -> unit

(* ======================================================================
 * History:
 * 
 * $Log: netcgi_fcgi_10.mli,v $
 * Revision 1.2  2004/07/24 18:30:49  stolpmann
 * 	ocamldoc
 *
 * Revision 1.1  2003/10/07 17:39:32  stolpmann
 * 	Imported Eric's patch for fastcgi
 *
 * 
 *)
